@@ -1,5 +1,7 @@
 from abc import abstractmethod
 import hashlib
+
+from yaml.scanner import ScannerError
 from .base import Extension
 from typing import Any, Dict, Optional, Sequence, List, Set
 from pathlib import Path
@@ -144,10 +146,14 @@ class RawChunk:
         return self.lines[0]
 
     def _get_reference(self):
+        # TODO check if this is called too often
         if self.type == RawChunkType.YAML:
-            self.dictionary = yaml.safe_load("".join(self.lines))
-            if "ref" in self.dictionary:
-                return self.path / self.dictionary["ref"]
+            try:
+                self.dictionary = yaml.safe_load("".join(self.lines))
+                if "ref" in self.dictionary:
+                    return self.path / self.dictionary["ref"]
+            except ScannerError as se:
+                self.report.error(f"Error parsing YAML {se}")
         return None
 
 
