@@ -1,5 +1,5 @@
 from pathlib import Path
-from typing import Optional
+from typing import Any, Optional
 
 import click
 
@@ -40,6 +40,19 @@ def supermark():
     ...
 
 
+def ensure_path(path: Any) -> Optional[Path]:
+    if path is None:
+        return None
+    elif isinstance(path, Path):
+        return path
+    elif isinstance(path, bytes):
+        return Path(path.decode("utf-8"))
+    elif isinstance(path, str):
+        return Path(path)
+    else:
+        raise ValueError()
+
+
 @supermark.command(help="Build a project, site or document.")
 @click.option(
     "-a",
@@ -119,6 +132,8 @@ def build(
     core = Core(report=report)
     print(logo_2(__version__))
     print_pandoc_info()
+    input = ensure_path(input)
+    output = ensure_path(output)
     format = "html"
     base_path = input or Path.cwd()
     input_path = base_path / "pages"
