@@ -39,4 +39,4 @@ def _write_file(base_path: Path, file: str, folder: str, content: str):
 
 
 def setup_github_action(base_path: Path):
-    _write_file(base_path, "build-site.yml", ".github/worflows/", GITHUB_ACTION)
+    _write_file(base_path, "build-site.yml", ".github/workflows/", GITHUB_ACTION)
